@@ -1,3 +1,3 @@
-from .worker import Worker
+from .worker import Worker, WorkerConnector
 from .common import singleton
 from .gazetteer import GazetteerTermExtractor
\ No newline at end of file
